@@ -1,5 +1,5 @@
 package WWW::AzimuthAero;
-$WWW::AzimuthAero::VERSION = '0.3';
+$WWW::AzimuthAero::VERSION = '0.31';
 
 # ABSTRACT: Parser for https://azimuth.aero/
 
@@ -52,9 +52,10 @@ sub get {
     confess "to is not defined"   unless defined $params{to};
     confess "date is not defined" unless defined $params{date};
     confess "date is not defined" unless defined $params{date};
-    confess "adults > 9" if ( $params{adults} > 9 );
 
     $params{adults} = 1 unless defined $params{adults};
+    confess "adults > 9"
+      if ( defined $params{adults} && ( $params{adults} > 9 ) );
 
     my $url =
         'https://booking.azimuth.aero/!/'
@@ -352,7 +353,7 @@ WWW::AzimuthAero - Parser for https://azimuth.aero/
 
 =head1 VERSION
 
-version 0.3
+version 0.31
 
 =head1 SYNOPSIS
 
